Package: SMAD
Type: Package
Title: Statistical Modelling of AP-MS Data (SMAD)
Version: 1.27.0
Authors@R: c(
    person("Qingzhou", "Zhang", , "zqzneptune@hotmail.com", c("aut", "cre")))
Description: Assigning probability scores to protein interactions captured in 
    affinity purification mass spectrometry (AP-MS) expriments to infer 
    protein-protein interactions. The output would facilitate non-specific 
    background removal as contaminants are commonly found in AP-MS data.
Depends: R (>= 3.6.0), RcppAlgos
Imports: magrittr (>= 1.5), dplyr, stats, tidyr, utils, Rcpp (>= 1.0.0)
LinkingTo: Rcpp
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
Suggests: knitr, rmarkdown, testthat, BiocStyle
VignetteBuilder: knitr
biocViews: MassSpectrometry, Proteomics, Software
git_url: https://git.bioconductor.org/packages/SMAD
git_branch: devel
git_last_commit: 3337822
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: yes
Packaged: 2025-10-30 23:06:55 UTC; biocbuild
Author: Qingzhou Zhang [aut, cre]
Maintainer: Qingzhou Zhang <zqzneptune@hotmail.com>

# Generated by roxygen2: do not edit by hand

export(CompPASS)
export(DICE)
export(HG)
export(Hart)
export(PE)
exportPattern('^[[:alpha:]]+')
import(Rcpp)
importFrom(Rcpp,evalCpp)
importFrom(RcppAlgos,comboGeneral)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,summarise)
importFrom(magrittr,"%>%")
importFrom(stats,phyper)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
importFrom(utils,unstack)
useDynLib(SMAD)

# Statistical Modelling of AP-MS Data (SMAD)

This R package implements statistical modelling of affinity purification–mass spectrometry (AP-MS) data to compute confidence scores to identify *bona fide* protein-protein interactions (PPI).

## Installation

The development version can be installed through github:
```{r}
 devtools::install_github(repo="zqzneptune/SMAD")
 library(SMAD)
```
## Input Data
A demo data.frame was provided as a hint how the input data should strcutured in order to run the scoring functions:

```{r}
data(TestDatInput)
colnames(TestDataInput)

[1] "idRun" "idBait" "idPrey" "countPrey" "lenPrey" 
```

|idRun|idBait|idPrey|countPrey|lenPrey|
|-----|:----:|:----:|:-------:|-------|
|Unique ID of one AP-MS run|Bait ID|Prey ID|Prey peptide count|Protein sequence length of the prey|

In case of duplcates, a suffix or prefix of e.g. "A", "B" could be added to **idRun** in order to make **"idRun-idBait"** combination unique to each replicate.

## Run scoring

### 1. CompPASS

Comparative Proteomic Analysis Software Suite (CompPASS) is based on spoke model. This algorithm was developed by Dr. Mathew Sowa for defining the human deubiquitinating enzyme interaction landscape [(Sowa, Mathew E., et al., 2009)][1]. The implementation of this algorithm was inspired by Dr. Sowa's [online tutorial][2]. The output includes Z-score, S-score, D-score and WD-score. In its implementation in BioPlex 1.0 [(Huttlin, Edward L., et al., 2015)][3] and 
BioPlex 2.0 [(Huttlin, Edward L., et al., 2017)][4], a naive 
Bayes classifier that learns to distinguish true interacting proteins from 
non-specific background and false positive identifications was included in the 
compPASS pipline. This function was optimized from the [source code][5].

The input data.frame, *datInput*, should include:**idRun**, **idBait**, **idPrey** and **countPrey**.

```{r}
datScore <- CompPASS(datInput)
```

### 2. DICE

The Dice coefficient is used to score the interaction scores across prey pair-wise combinations, which was proposed by [(Bing Zhang et al., 2008)][9]

The input data.frame, *datInput*, should include:**idRun** and **idPrey**.

```{r}
datScore <- DICE(datInput)
```

### 3. Hart

Hart scoring algorithm is based on a hypergeometric distribution error model [(Hart et al., 2007)][6].

The input data.frame, *datInput*, should include:**idRun** and **idPrey**.

```{r}
datScore <- Hart(datInput)
```


### 4. HGScore

HGScore algorithm is based on a hypergeometric distribution error model [(Hart et al., 2007)][6] with incorporation of NSAF [(Zybailov, Boris, et al., 2006)][7]. This algorithm was first introduced to predict the protein complex network of Drosophila melanogaster [(Guruharsha, K. G., et al., 2011)][8]. This scoring algorithm was based on matrix model. 

The input data.frame, *datInput*, should include:**idRun**, **idPrey**, **countPrey** and **lenPrey**.

```{r}
datScore <- HG(datInput)
```

### 5. PE
PE incorporated both spoke and matrix model as repored in [(Sean R. Collins, et al., 2007)][10].

The input data.frame, *datInput*, should include:**idRun**, **idBait** and **idPrey**.

```{r}
datScore <- PE(datInput)
```



## License

MIT @ Qingzhou Zhang

[1]: https://doi.org/10.1016/j.cell.2009.04.042
[2]: http://besra.hms.harvard.edu/ipmsmsdbs/cgi-bin/tutorial.cgi
[3]: https://doi.org/10.1016/j.cell.2015.06.043
[4]: https://www.nature.com/articles/nature22366
[5]: https://github.com/dnusinow/cRomppass
[6]: https://doi.org/10.1186/1471-2105-8-236
[7]: https://doi.org/10.1021/pr060161n
[8]: https://doi.org/10.1016/j.cell.2011.08.047
[9]: https://doi.org/10.1093/bioinformatics/btn036
[10]: https://doi.org/10.1074/mcp.M600381-MCP200

#' PE
#' Incorporated both spoke and matrix model.
#'
#' @title PE
#' @param datInput A dataframe with column names: idRun, idBait, idPrey, 
#' Each row represent one unique protein captured in one pull-down 
#' experiment.
#' @param rBait The value of the 'r' parameter as desribed in the publication.
#'
#' @param cntPseudo The value of the 'pseudo count' parameter.
#' @return A dataframe consists of protein-protein interactions from both Spoke 
#' and Matrix model.
#'
#' @author Qingzhou Zhang, \email{zqzneptune@hotmail.com}
#' @references Collins, Sean R., et al. "Toward a comprehensive atlas of the 
#' physical interactome of Saccharomyces cerevisiae." 
#' Molecular & Cellular Proteomics 6.3 (2007): 439-450.
#' \url{https://doi.org/10.1074/mcp.M600381-MCP200}
#' 
#' @importFrom tidyr separate
#' @importFrom dplyr group_by
#' @importFrom dplyr summarise
#' @importFrom dplyr mutate
#' @importFrom dplyr left_join
#' @importFrom dplyr filter
#' @importFrom dplyr n
#' @importFrom magrittr %>%
#' @importFrom utils unstack
#' @importFrom RcppAlgos comboGeneral
#' @useDynLib SMAD
#' @exportPattern '^[[:alpha:]]+'
#' @export
#' @examples
#' data(TestDatInput)
#' datScore <- PE(TestDatInput, 0.37, 1)
#' head(datScore)

PE <- function(datInput, rBait = 0.37, cntPseudo = 1){
    colInput <-
        c("idRun", "idBait", "idPrey")
    
    if(!is.data.frame(datInput)){
        stop("Input data should be data.frame")
    }
    
    if(!all(colInput %in% colnames(datInput))){
        missingCol <-
            setdiff(colInput, 
                    colnames(datInput)[match(colInput, colnames(datInput))])
        stop("Input data missing: ", paste(missingCol, collapse = ", "))
    }
    # .getPPI <- function(prts){
    #     if(length(prts) < 2){
    #         return(NA)
    #     }else{
    #         pps <-
    #             combn(prts, 2)
    #         s <-
    #             apply(pps, 2, sort)
    #         return(paste(s[1, ], s[2, ], sep = "~"))
    #     }
    # }
    . <- NULL
    BP <- NULL
    Freq <- NULL
    cntBP <- NULL
    cntBait <- NULL
    cntPry <- NULL
    f <- NULL
    idBait <- NULL
    idPrey <- NULL
    idRun <- NULL
    nonBP <- NULL
    obsPry <- NULL
    p <- NULL
    sSum <- NULL
    totPPS <- NULL
    datInput <-
        datInput[datInput$idBait != datInput$idPrey, ]
    # Generating Bair-idPrey space
    s <-
        apply(datInput[, c("idBait", "idPrey")], 1, sort)
    pkBP <-
        unique(paste(s[1, ], s[2, ], sep = "~"))
    
    # Generating idPrey-idPrey space
    pkPrys <-
        unstack(datInput[, c("idPrey", "idRun")])
    pkPPS <-
        lapply(pkPrys, function(prts){
            if(length(prts) < 2){
                return(NA)
            }else{
                sPrts <-
                    sort(prts)
                pps <-
                    comboGeneral(sPrts, 2)
                return(paste(pps[, 1], pps[, 2], sep = "~"))
            }
        })
        # bplapply(pkPrys, FUN = .getPPI, BPPARAM = MulticoreParam(workers = 8))
    
    pkPP <-
        unique(unlist(pkPPS))
    # Final PPI space
    ppsOut <-
        data.frame(`PPI` = unique(c(pkBP, pkPP)),
                   stringsAsFactors = FALSE) %>% 
        separate(data = ., col = "PPI",
                 into = c("InteractorA", "InteractorB"),
                 sep = "~",
                 remove = FALSE)
    ppsOut[, "BP"] <-
        paste(ppsOut$InteractorA, ppsOut$InteractorB, sep = ":")
    ppsOut[, "PB"] <-
        paste(ppsOut$InteractorB, ppsOut$InteractorA, sep = ":")
    
    totObsPry <- length(datInput$idPrey) ### Total number of idPrey observations. (Redundant)
    nDistPry <- length(unique(datInput$idPrey)) # Total number of distinct preys.
    pkBait <-
        unique(datInput[, c("idRun", "idBait")])
    nPkBait <-
        as.data.frame(table(pkBait$idBait), stringsAsFactors = FALSE)
    colnames(nPkBait) <-
        c("idBait", "cntBait") # Bait and number of times each bait purified
    nObsPry <-
        as.data.frame(table(datInput$idPrey), stringsAsFactors = FALSE)
    colnames(nObsPry) <-
        c("idPrey", "obsPry") # idPrey and numebr of times each idPrey observed
    fPrey <-  # Frequency of idPrey captured across all purifications as in (Eq.9)
        nObsPry %>% 
        mutate(`f` = (`obsPry` + cntPseudo)/(totObsPry + (nDistPry * cntPseudo)))
    
    cPkPry <- # Number preys in each purifications, replicates calculated individually
        datInput %>% 
        group_by(`idBait`, `idRun`) %>% 
        summarise(`cntPry` = n())
    pkBP <- # Number of bait-idPrey pairs observed
        datInput %>% 
        group_by(`idBait`, `idPrey`) %>% 
        summarise(`totBP` = n()) %>% 
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = ":"))
    dS <- # S for each idRun-bait-idPrey 
        datInput %>% 
        left_join(., nPkBait, by = "idBait") %>% 
        left_join(., fPrey[, c("idPrey", "f")], by = "idPrey") %>% 
        left_join(., cPkPry[, c("idRun", "cntPry")], by = "idRun") %>% 
        mutate(`p` = 1 - exp((-1) * `f` * `cntPry` * `cntBait`)) %>% #(Eq.8)
        mutate(`s` = log10((rBait + (1 - rBait) * `p`)/`p`)) %>% #(Eq.6)
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = ":"))
    pkS <- # Sum across bait-idPrey captured
        dS[, c("BP", "s")] %>% 
        group_by(`BP`) %>% 
        mutate(`cntBP` = n(), `sSum` = sum(`s`))
    pkSU <-
        unique(pkS[, c("BP", "cntBP", "sSum")])
    sNoPrey <-
        log10(1 - rBait) # (Eq.7)
    
    spacePk <-
        expand.grid(`idBait` = unique(datInput$idBait),
                    `idPrey` = unique(datInput$idPrey),
                    stringsAsFactors = FALSE) %>% 
        filter(`idBait` != `idPrey`) %>% 
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = ":")) %>% 
        left_join(., pkSU, by = "BP") %>% 
        left_join(., nPkBait, by = "idBait")
    spacePk[is.na(spacePk)] <- 0
    finalS <-
        spacePk %>% 
        mutate(`nonBP` = `cntBait` - `cntBP`) %>%
        mutate(`finalS` = `sSum` + `nonBP` * sNoPrey)
    spokeBP <-
        finalS[, c("BP", "finalS")]
    colnames(spokeBP) <-
        c("BP", "spokeBP")
    spokePB <-
        finalS[, c("BP", "finalS")]
    colnames(spokePB) <-
        c("PB", "spokePB")
    totPkList <-
        unstack(datInput[, c("idPrey", "idRun")])
    f_1 <- fPrey[, c("idPrey", "f")]
    colnames(f_1) <- c("pry1", "f_1")
    f_2 <- fPrey[, c("idPrey", "f")]
    colnames(f_2) <- c("pry2", "f_2")
    
    totPP <-
        as.data.frame(table(unlist(pkPPS)), stringsAsFactors = FALSE)
    colnames(totPP) <-
        c("PPI", "Freq")
    
    totPP[, "totPPS"] <-
        length(unlist(pkPPS))
    pkM <-
        separate(data = totPP,
                 col = "PPI",
                 into = c("pry1", "pry2"),
                 sep = "~",
                 remove = FALSE) %>% 
        left_join(., f_1, by = "pry1") %>% 
        left_join(., f_2, by = "pry2") %>% 
        mutate(`p` = 1 - exp(-`f_1` * `f_2` * `totPPS`)) %>% 
        mutate(`finalM` = (log10((rBait + (1 - rBait) * `p`)/`p`)) * `Freq`)
    
    finalM <-
        unique(pkM[, c("PPI", "finalM")])
    colnames(finalM) <-
        c("PPI", "matrixPP")
    peOut <-
        ppsOut %>% 
        left_join(., spokeBP, by = c("BP")) %>% 
        left_join(., spokePB, by = c("PB")) %>% 
        left_join(., finalM, by = "PPI")
    peOut[, "PE"] <-
        rowSums(peOut[, c("spokeBP", "spokePB", "matrixPP")], na.rm = TRUE)
    return(peOut)
}

#' CompPASS
#' Comparative Proteomic Analysis Software Suite (CompPASS) is based on spoke
#' model. This algorithm was developed by Dr. Mathew Sowa for defining the
#' human deubiquitinating enzyme interaction landscape
#' (Sowa, Mathew E., et al., 2009). The implementation of this algorithm was
#' inspired by Dr. Sowa's online tutorial
#' (\url{http://besra.hms.harvard.edu/ipmsmsdbs/cgi-bin/tutorial.cgi}).
#' The output includes Z-score, S-score, D-score and WD-score.
#' This function also computes entropy and normalized 
#' WD-score. The source  code for this function was based on the source code. 
#'  \url{https://github.com/dnusinow/cRomppass}
#'
#'
#' @title CompPASS
#' @param datInput A dataframe with column names: idRun, idBait, idPrey, 
#' countPrey. Each row represent one unique protein captured in one 
#' pull-down experiment
#' @return A data frame consists of unique bait-prey pairs with 
#' Z-score, S-score,D-score and WD-score indicating interacting probabilities.

#' @author Qingzhou Zhang, \email{zqzneptune@hotmail.com}
#' 
#' @references Sowa, Mathew E., et al. "Defining the human deubiquitinating
#' enzyme interaction landscape." Cell 138.2 (2009): 389-403.
#' \url{https://doi.org/10.1016/j.cell.2009.04.042}
#' @references Huttlin, Edward L., et al. "The BioPlex network: a systematic 
#' exploration of the human interactome." Cell 162.2 (2015): 425-440. 
#' \url{https://doi.org/10.1016/j.cell.2015.06.043}
#' @references Huttlin, Edward L., et al. "Architecture of the human 
#' interactome defines protein communities and disease networks." 
#' Nature 545.7655 (2017): 505. 
#' \url{https://www.nature.com/articles/nature22366}

#' @importFrom dplyr group_by
#' @importFrom dplyr summarise
#' @importFrom dplyr mutate
#' @importFrom dplyr left_join
#' @importFrom dplyr filter
#' @importFrom dplyr n
#' @importFrom tidyr spread
#' @importFrom magrittr %>%
#' @importFrom stats quantile
#' @export
#' @examples
#' data(TestDatInput)
#' datScore <- CompPASS(TestDatInput)
#' head(datScore)
CompPASS <- function(datInput){
    colInput <-
        c("idRun", "idBait", "idPrey", "countPrey")
    
    if(!is.data.frame(datInput)){
        stop("Input data should be data.frame")
    }
    
    if(!all(colInput %in% colnames(datInput))){
        missingCol <-
            setdiff(colInput, 
                    colnames(datInput)[match(colInput, colnames(datInput))])
        stop("Input data missing: ", paste(missingCol, collapse = ", "))
    }
    
    . <- NULL
    idPrey <- NULL
    idBait <- NULL
    idRun <- NULL
    countPrey <- NULL
    MaxTSC <- NULL
    nBait <- NULL
    f_sum <- NULL
    AvePSM <- NULL
    MeanDiff <- NULL
    Mean <- NULL
    SD <- NULL
    WD_inner <- NULL
    WD_raw <- NULL
    WD_raw.factor <- NULL
    
    # Use total number of baits instead of actual AP-MS runs as
    # total number of experiments.
    # Multiple runs for the same bait were considered as replicated
    k <-
        length(unique(datInput$idBait))
    # f_sum: number of runs capturing the same prey
    f <-
        unique(datInput[, c("idBait", "idPrey")]) %>%
        group_by(`idPrey`) %>%
        summarise(`f_sum` = n())
    # p: number of replicates the bait-prey pair captured
    p <-
        datInput[, c("idBait", "idPrey")] %>%
        group_by(`idBait`, `idPrey`) %>%
        summarise(`p` = n()) %>%
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = "~"))
    # Using MAXIMUM spectral count to compute Entropy
    e <-
        datInput %>%
        group_by(`idBait`, `idPrey`, `idRun`) %>%
        summarise(`MaxTSC` = max(`countPrey`)) %>% 
        mutate(`p` = (`MaxTSC` + 1/length(`MaxTSC`))/(sum(`MaxTSC`) + 1)) %>% 
        mutate(`Entropy` = sum(unlist(lapply(`p`, function(x) {
            -1*x*log(x, 2) 
        })))) %>%
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = "~"))
    # AvePSM = average speactral counts across replicates.
    stats <-
        datInput %>%
        group_by(`idBait`, `idPrey`) %>%
        summarise(`AvePSM` = mean(`countPrey`)) %>%
        mutate(`BP` = paste(`idBait`, `idPrey`, sep = "~"))
    dat <-
        stats %>%
        left_join(., unique(e[, c("BP", "Entropy")]), by = "BP") %>%
        left_join(., f, by = "idPrey") %>%
        left_join(., p[, c("BP", "p")], by = "BP") %>%
        mutate(`k` = k)
    
    preyWithBaitOnly <-
        stats %>%
        group_by(`idPrey`) %>%
        summarise(`nBait` = n()) %>%
        filter(`nBait` == 1) %>%
        .$idPrey
    dat <-
        dat %>%
        mutate(`f_num_no_prey` =
                ifelse((`idBait` == `idPrey`)&(`idPrey` %in% preyWithBaitOnly),
                            k, k-`f_sum`))
    df_num_no_prey <-
        unique(dat[, c("idPrey", "f_num_no_prey")])
    f_num_no_prey <-
        df_num_no_prey$f_num_no_prey
    names(f_num_no_prey) <-
        df_num_no_prey$idPrey
    statsM <-
        stats %>%
        mutate(`AvePSM` = ifelse(`idBait` != `idPrey`,
                                    `AvePSM`,
                                    ifelse(`idPrey` %in% preyWithBaitOnly, 
                                        `AvePSM`, NA)))
    statsMatrix <-
        spread(`statsM`[, c("idBait", "idPrey", "AvePSM")], `idBait`, `AvePSM`)
    m <-
        as.matrix(statsMatrix[, -1])
    rownames(m) <-
        statsMatrix$idPrey 
    prey.mean <-
        rowSums(m, na.rm = TRUE) / k
    
    prey.stats <-
        data.frame(`idPrey` = names(prey.mean),
                    `Mean` = prey.mean,
                    `MeanDiff` = rowSums((m - prey.mean)^2, na.rm = TRUE),
                    `f_num_no_prey` = f_num_no_prey[names(prey.mean)],
                    stringsAsFactors = FALSE) %>%
        mutate(`SD` =  
                sqrt((`MeanDiff` + ((`Mean`^2) * (`f_num_no_prey`)))/(k - 1)))
    avePSM <-
        left_join(`dat`, prey.stats[, c("idPrey", "Mean", "SD")], by = "idPrey")
    output <-
        avePSM %>%
        mutate(`scoreZ` = (`AvePSM` - `Mean`) / (`SD`)) %>%
        mutate(`scoreS` = sqrt((`AvePSM`) * (`k`) / (`f_sum`))) %>%
        mutate(`scoreD` = sqrt((`AvePSM`) * (((`k`) / (`f_sum`))^`p`))) %>%
        mutate(`WD_inner` = (`k` / `f_sum`) * (`SD` / `Mean`)) %>%
        mutate(`WD_raw` = sqrt(`AvePSM` * (`WD_inner`^`p`)))
    
    # Weighted WD score
    i = !(is.na(output$WD_raw) | is.nan(output$WD_raw))
    WD_raw <-
        output$WD_raw[i]
    WD_raw.factor <-
        unname(quantile(WD_raw, 0.98)[1])
    
    output[i, "scoreWD"] <-
        WD_raw / WD_raw.factor
    
    output <-
        as.data.frame(output[, c("idBait", "idPrey", "AvePSM",
                                 "scoreZ", "scoreS", "scoreD",
                                    "Entropy", "scoreWD")])
    return(output)
}

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
library(SMAD)
data("TestDatInput")
head(TestDatInput)

## ----echo=TRUE, message=FALSE, warning=FALSE----------------------------------
scoreCompPASS <- CompPASS(TestDatInput)
head(scoreCompPASS)

## ----CompPASS output figure, echo=FALSE, fig.height=7, fig.width=7, message=FALSE, warning=FALSE, paged.print=FALSE----
par(mfrow = c(2, 2))
plot(sort(scoreCompPASS$scoreZ, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "Z-score")
plot(sort(scoreCompPASS$scoreS, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "S-score")
plot(sort(scoreCompPASS$scoreD, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "D-score")
plot(sort(scoreCompPASS$scoreWD, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "WD-score")


## -----------------------------------------------------------------------------
scoreHG <- HG(TestDatInput)
head(scoreHG)

## ----HG output figure, echo=FALSE, fig.height=7, fig.width=7, message=FALSE, warning=FALSE, paged.print=FALSE----

plot(sort(scoreHG$HG, decreasing = TRUE), pch = 16,
     xlab = "Ranked prey-prey interactions",
     ylab = "HGscore")

#' Hart
#' Scoring algorithm based on a hypergeometric distribution error model (Hart et al.,2007).
#'
#' @title Hart
#' @param datInput A dataframe with column names: idRun, idPrey. 
#' Each row represent one unique protein captured in one pull-down experiment.
#'
#' @return A dataframe consists of pairwise combindation of preys identified in 
#' the input with Hart scores indicating interacting probabilities computed from 
#' negative log transformed Hypergeometric test P-values.
#'
#' @author Qingzhou Zhang, \email{zqzneptune@hotmail.com}
#' @references Hart, G. Traver, Insuk Lee, and Edward M. Marcotte. 
#' 'A high-accuracy consensus map of yeast protein complexes reveals modular 
#' nature of gene essentiality.' BMC bioinformatics 8.1 (2007): 236.
#' \url{https://doi.org/10.1186/1471-2105-8-236}

#' @importFrom dplyr group_by
#' @importFrom dplyr summarise
#' @importFrom dplyr mutate
#' @importFrom dplyr left_join
#' @importFrom dplyr filter
#' @importFrom dplyr n
#' @importFrom tidyr separate
#' @importFrom tidyr spread
#' @importFrom magrittr %>%
#' @importFrom stats phyper
#' @importFrom RcppAlgos comboGeneral
#' @useDynLib SMAD
#' @exportPattern '^[[:alpha:]]+'
#' @export
#' @examples
#' data(TestDatInput)
#' datScore <- Hart(TestDatInput)
#' head(datScore)


Hart <- function(datInput) {
    colInput <-
        c("idRun", "idPrey")
    
    if(!is.data.frame(datInput)){
        stop("Input data should be data.frame")
    }
    
    if(!all(colInput %in% colnames(datInput))){
        missingCol <-
            setdiff(colInput, 
                    colnames(datInput)[match(colInput, colnames(datInput))])
        stop("Input data missing: ", paste(missingCol, collapse = ", "))
    }
    
    
    . <- NULL
    idRun <- NULL
    idPrey <- NULL
    Tn <- NULL
    UniprotID <- NULL
    tnA <- NULL
    tnB <- NULL
    NMinTn <- NULL
    ppiTN <- NULL
    Freq <- NULL
    TnA <- NULL
    totTn <- NULL
    TnB <- NULL
    
    datCnt <-
        unique(datInput[, c("idRun", "idPrey")])
    tnInteractor <- 
        datCnt %>% 
        group_by(`idPrey`) %>% 
        summarise(`Tn` = n())
    tnA <-
        tnInteractor
    colnames(tnA) <-
        c("InteractorA", "TnA")
    tnB <-
        tnInteractor
    colnames(tnB) <-
        c("InteractorB", "TnB")
    listCnt <-
        unstack(datCnt[, c("idPrey", "idRun")])
    listPPI <-
        lapply(listCnt, function(prt){
            if(length(prt) > 1){
                sPrt <- 
                    sort(prt)
                ps <-
                    comboGeneral(sPrt, 2)
                return(paste(ps[, 1], ps[, 2], sep = "~"))
            }else{
                return(NA)
            }
        })
    datPPI <-
        as.data.frame(table(unlist(listPPI)), stringsAsFactors = FALSE)
    colnames(datPPI) <-
        c("PPI", "Freq")
    scorePPI <- 
        datPPI %>% 
        separate(data = ., col = "PPI",
                 into = c("InteractorA", "InteractorB"),
                 sep = "~", remove = FALSE) %>% 
        left_join(., tnA, by = "InteractorA") %>% 
        left_join(., tnB, by = "InteractorB") %>% 
        mutate(`totTn` = sum(tnInteractor$Tn)) %>% 
        mutate(`Hart` = -phyper(`Freq`, `TnA`, `totTn` - `TnB`, 
                                `TnB`, lower.tail = FALSE, log.p = TRUE)) %>% 
        filter(!is.infinite(`Hart`))
    return(scorePPI)
}

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.GetDICE <- function(mat) {
    .Call('_SMAD_GetDICE', PACKAGE = 'SMAD', mat)
}

.GetPPN <- function(mat) {
    .Call('_SMAD_GetPPN', PACKAGE = 'SMAD', mat)
}

#' Test data for SMAD 
#'
#' \itemize{
#'   \item idRun A unique identifier for one AP-MS run
#'   \item idBait A unique identifier for the bait protein
#'   \item idPrey A unique identifier for the prey protein
#'   \item countPrey Sepctra/Peptider count for the prey protein
#'   \item lenPrey Protein length for the prey protein
#' }
#' @description It is a subset of unfiltered BioPlex 2.0 consisting of
#' apoptosis as bait proteins
#' @docType data
#' @keywords datasets
#' @name TestDatInput 
#' @usage data(TestDatInput)
#' @format A data frame with 5000 rows and 5 variables
NULL

#' HGScore
#' Scoring algorithm based on a hypergeometric distribution error model 
#' (Hart et al.,2007) with incorporation of NSAF (Zybailov, Boris, et al., 2006)
#' . This algorithm was first introduced to predict the protein complex network 
#' of Drosophila melanogaster (Guruharsha, K. G., et al., 2011). This scoring 
#' algorithm was based on matrix model.
#'
#' @title HGScore
#' @param datInput A dataframe with column names: idRun, idPrey, countPrey, 
#' lenPrey. Each row represent one unique protein captured in one pull-down 
#' experiment.
#'
#' @return A dataframe consists of pairwise combindation of preys identified in 
#' the input with HG scores indicating interacting probabilities computed from 
#' negative log transformed Hypergeometric test P-values.
#'
#' @author Qingzhou Zhang, \email{zqzneptune@hotmail.com}
#' @references Guruharsha, K. G., et al. 'A protein complex network of 
#' Drosophila melanogaster.' Cell 147.3 (2011): 690-703.
#' \url{https://doi.org/10.1016/j.cell.2011.08.047}
#' @references Hart, G. Traver, Insuk Lee, and Edward M. Marcotte. 
#' 'A high-accuracy consensus map of yeast protein complexes reveals modular 
#' nature of gene essentiality.' BMC bioinformatics 8.1 (2007): 236.
#' \url{https://doi.org/10.1186/1471-2105-8-236}
#' @references Zybailov, Boris, et al. 'Statistical analysis of membrane 
#' proteome expression changes in Saccharomyces c erevisiae.' Journal of 
#' proteome research 5.9 (2006): 2339-2347.
#' \url{https://doi.org/10.1021/pr060161n}

#' @importFrom dplyr group_by
#' @importFrom dplyr summarise
#' @importFrom dplyr mutate
#' @importFrom dplyr left_join
#' @importFrom dplyr filter
#' @importFrom dplyr n
#' @importFrom tidyr spread
#' @importFrom magrittr %>%
#' @importFrom dplyr bind_rows
#' @importFrom stats setNames
#' @importFrom stats phyper
#' @importFrom RcppAlgos comboGeneral
#' @import Rcpp
#' @importFrom Rcpp evalCpp
#' @useDynLib SMAD
#' @exportPattern '^[[:alpha:]]+'
#' @export
#' @examples
#' data(TestDatInput)
#' datScore <- HG(TestDatInput)
#' head(datScore)


HG <- function(datInput) {
    colInput <-
        c("idRun", "idPrey", "countPrey", "lenPrey")
    
    if(!is.data.frame(datInput)){
        stop("Input data should be data.frame")
    }
    
    if(!all(colInput %in% colnames(datInput))){
        missingCol <-
            setdiff(colInput, 
                    colnames(datInput)[match(colInput, colnames(datInput))])
        stop("Input data missing: ", paste(missingCol, collapse = ", "))
    }
    . <- NULL
    idRun <- NULL
    countPrey <- NULL
    lenPrey <- NULL
    NormalSpec <- NULL
    SumNS <- NULL
    NSAF <- NULL
    NormalNSAF <- NULL
    Tn <- NULL
    UniprotID <- NULL
    tnA <- NULL
    tnB <- NULL
    NMinTn <- NULL
    HG <- NULL
    ppiTN <- NULL
    s <- NULL
    InteractorA <- NULL
    InteractorB <- NULL
    datCnt <- 
        datInput %>% 
        mutate(`NormalSpec` = `countPrey`/`lenPrey`) %>% 
        group_by(`idRun`) %>% 
        mutate(`SumNS` = sum(`NormalSpec`)) %>% 
        mutate(`NSAF` = `NormalSpec`/`SumNS`) %>% 
        group_by(`idRun`) %>% 
        mutate(`NormalNSAF` = `NSAF`/min(`NSAF`)) %>% 
        mutate(`Tn` = as.integer(sqrt(`NormalNSAF`)))
    d <- spread(datCnt[, c("idRun", "idPrey", "Tn")], 
                `idRun`, `Tn`)
    g <- as.matrix(d[, -1])
    g[is.na(g)] <- 0
    g <- t(g)
    colnames(g) <- d$idPrey
    pps <- 
        comboGeneral(colnames(g), 2)
    PPN <- .GetPPN(g)
    CppPPN <- PPN[lower.tri(PPN, diag = FALSE)]
    datPPI <- data.frame(cbind(pps[CppPPN != 0, ], 
                                CppPPN[CppPPN != 0]), stringsAsFactors = FALSE)
    colnames(datPPI) <- 
        c("InteractorA", "InteractorB", "ppiTN")
    datPPI$ppiTN <- 
        as.numeric(datPPI$ppiTN)
    tnInteractorA <- 
        datPPI[, c("InteractorA", "ppiTN")]
    colnames(tnInteractorA) <- 
        c("UniprotID", "ppiTN")
    tnInteractorB <- 
        datPPI[, c("InteractorB", "ppiTN")]
    colnames(tnInteractorB) <- 
        c("UniprotID", "ppiTN")
    tnProtein <- 
        bind_rows(tnInteractorA, tnInteractorB) %>% 
        group_by(`UniprotID`) %>% 
        summarise(minTn = sum(`ppiTN`))
    sumMinTnInteractorA <- 
        tnProtein
    colnames(sumMinTnInteractorA) <- 
        c("InteractorA", "tnA")
    sumMinTnInteractorB <- 
        tnProtein
    colnames(sumMinTnInteractorB) <- 
        c("InteractorB", "tnB")
    scorePPI <- 
        datPPI %>% 
        left_join(., sumMinTnInteractorA, by = "InteractorA") %>% 
        left_join(., sumMinTnInteractorB, by = "InteractorB") %>% 
        mutate(`PPI` = paste(`InteractorA`, `InteractorB`, sep = "~")) %>% 
        mutate(`NMinTn` = sum(tnProtein$minTn)/2) %>% 
        mutate(`HG` = -phyper(`ppiTN`, `tnA`, `NMinTn` - `tnB`, 
                                `tnB`, lower.tail = FALSE, log.p = TRUE))
    return(scorePPI)
}

#' DICE
#' The Dice coefficient is used to score the interaction affinity between two proteins. 
#'
#' @title DICE
#' @param datInput A dataframe with column names: idRun, idPrey.
#' Each row represent one unique protein captured in one pull-down 
#' experiment.
#'
#' @return A dataframe consists of pairwise combindation of preys identified in 
#' the input with DICE scores.
#'
#' @author Qingzhou Zhang, \email{zqzneptune@hotmail.com}
#' @references Bing Zhang et al., From pull-down data to protein interaction 
#' networks and complexes with biological relevance, Bioinformatics, 
#' Volume 24, Issue 7, 1 April 2008, Pages 979–986, 
#' \url{https://doi.org/10.1093/bioinformatics/btn036}

#' @importFrom tidyr spread
#' @importFrom magrittr %>%
#' @importFrom RcppAlgos comboGeneral
#' @import Rcpp
#' @importFrom Rcpp evalCpp
#' @useDynLib SMAD
#' @exportPattern '^[[:alpha:]]+'
#' @export
#' @examples
#' data(TestDatInput)
#' datScore <- DICE(TestDatInput)
#' head(datScore)


DICE <- function(datInput) {
    colInput <-
        c("idRun", "idPrey")
    
    if(!is.data.frame(datInput)){
        stop("Input data should be data.frame")
    }
    
    if(!all(colInput %in% colnames(datInput))){
        missingCol <-
            setdiff(colInput, 
                    colnames(datInput)[match(colInput, colnames(datInput))])
        stop("Input data missing: ", paste(missingCol, collapse = ", "))
    }
    . <- NULL
    idRun <- NULL
    countPrey <- NULL
    Tn <- NULL
    s <- NULL
    datCnt <-
        unique(datInput[, c("idRun", "idPrey")])
    datCnt[, "Tn"] <- 1
    d <- spread(datCnt[, c("idRun", "idPrey", "Tn")], # idPrey sorted already
                `idRun`, `Tn`)
    g <- as.matrix(d[, -1])
    g[is.na(g)] <- 0
    rownames(g) <- d$idPrey
    datDice <-
        .GetDICE(t(g))
    pps <- 
        comboGeneral(d$idPrey, 2)
    ppDice <- 
        datDice[lower.tri(datDice, diag = FALSE)]
    datPPI <- 
        data.frame(cbind(pps, ppDice), 
                   stringsAsFactors = FALSE)
    colnames(datPPI) <-
        c("InteractorA", "InteractorB", "DICE")
    datPPI$DICE <-
        as.numeric(datPPI$DICE)
    datPPI[, "PPI"] <-
        paste(datPPI$InteractorA, datPPI$InteractorB, sep = "~")
    return(datPPI)
}

---
title: "SMAD Quick Start"
author: 
- name: "Qingzhou (Johnson) Zhang"
  email: zqzneptune@hotmail.com
date: "`r Sys.Date()`"
package: SMAD
output: 
  BiocStyle::html_document:
    toc_float: true
vignette: >
  %\VignetteIndexEntry{SMAD Quick Start}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

# Introduction
This R package implements statistical modelling of affinity purification–mass 
spectrometry (AP-MS) data to compute confidence scores to identify *bona fide* 
protein-protein interactions (PPI).

# Prepare Input Data
Prepare input data into the dataframe *datInput* with the following format:

|idRun|idBait|idPrey|countPrey|lenPrey|
|-----|:----:|:----:|:-------:|:-------:|
|AP-MS run ID|Bait ID|Prey ID|Prey peptide count|Prey protein length|


```{r}
library(SMAD)
data("TestDatInput")
head(TestDatInput)
```

The test data is subset from the unfiltered BioPlex 2.0 data, which consists of
apoptosis proteins as baits.

# Methods

## CompPASS

Comparative Proteomic Analysis Software Suite (CompPASS) is based on spoke 
model. This algorithm was developed by Dr. Mathew Sowa for defining the human 
deubiquitinating enzyme interaction landscape [(Sowa, Mathew E., et al., 
2009)][1]. The implementation of this 
algorithm was inspired by Dr. Sowa's [online tutorial][2]. 
The output includes Z-score, S-score, D-score and WD-score. In its 
implementation in BioPlex 1.0 [(Huttlin, Edward L., et al., 2015)][3] and 
BioPlex 2.0 [(Huttlin, Edward L., et al., 2017)][4], a naive 
Bayes classifier that learns to distinguish true interacting proteins from 
non-specific background and false positive identifications was included in the 
compPASS pipline. This function was optimized from the [source code][5].

```{r echo=TRUE, message=FALSE, warning=FALSE}
scoreCompPASS <- CompPASS(TestDatInput)
head(scoreCompPASS)
```

Based on the scores, bait-prey interactions could be ranked and ready for downstream analyses.

```{r CompPASS output figure, echo=FALSE, fig.height=7, fig.width=7, message=FALSE, warning=FALSE, paged.print=FALSE}
par(mfrow = c(2, 2))
plot(sort(scoreCompPASS$scoreZ, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "Z-score")
plot(sort(scoreCompPASS$scoreS, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "S-score")
plot(sort(scoreCompPASS$scoreD, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "D-score")
plot(sort(scoreCompPASS$scoreWD, decreasing = TRUE), pch = 16,
     xlab = "Ranked bait-prey interactions",
     ylab = "WD-score")

```


## HGScore

HGScore Scoring algorithm based on a hypergeometric distribution error model 
[(Hart et al., 2007)][6] with incorporation of 
NSAF [(Zybailov, Boris, et al., 2006)][7]. This algorithm was first introduced 
to predict the protein complex network of Drosophila melanogaster 
[(Guruharsha, K. G., et al., 2011)][8]. This scoring algorithm was based on
matrix model. Unlike CompPASS, we need protein length for each prey in 
the additional column.

```{r}
scoreHG <- HG(TestDatInput)
head(scoreHG)
```

```{r HG output figure, echo=FALSE, fig.height=7, fig.width=7, message=FALSE, warning=FALSE, paged.print=FALSE}

plot(sort(scoreHG$HG, decreasing = TRUE), pch = 16,
     xlab = "Ranked prey-prey interactions",
     ylab = "HGscore")

```

Noted that HG scoring implements matrix models which leads to significant increase of inferred protein-protein interactions.


[1]: https://doi.org/10.1016/j.cell.2009.04.042
[2]: http://besra.hms.harvard.edu/ipmsmsdbs/cgi-bin/tutorial.cgi
[3]: https://doi.org/10.1016/j.cell.2015.06.043
[4]: https://www.nature.com/articles/nature22366
[5]: https://github.com/dnusinow/cRomppass
[6]: https://doi.org/10.1186/1471-2105-8-236
[7]: https://doi.org/10.1021/pr060161n
[8]: https://doi.org/10.1016/j.cell.2011.08.047

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Hart.R
\name{Hart}
\alias{Hart}
\title{Hart}
\usage{
Hart(datInput)
}
\arguments{
\item{datInput}{A dataframe with column names: idRun, idPrey. 
Each row represent one unique protein captured in one pull-down experiment.}
}
\value{
A dataframe consists of pairwise combindation of preys identified in 
the input with Hart scores indicating interacting probabilities computed from 
negative log transformed Hypergeometric test P-values.
}
\description{
Hart
Scoring algorithm based on a hypergeometric distribution error model (Hart et al.,2007).
}
\examples{
data(TestDatInput)
datScore <- Hart(TestDatInput)
head(datScore)
}
\references{
Hart, G. Traver, Insuk Lee, and Edward M. Marcotte. 
'A high-accuracy consensus map of yeast protein complexes reveals modular 
nature of gene essentiality.' BMC bioinformatics 8.1 (2007): 236.
\url{https://doi.org/10.1186/1471-2105-8-236}
}
\author{
Qingzhou Zhang, \email{zqzneptune@hotmail.com}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DICE.R
\name{DICE}
\alias{DICE}
\title{DICE}
\usage{
DICE(datInput)
}
\arguments{
\item{datInput}{A dataframe with column names: idRun, idPrey.
Each row represent one unique protein captured in one pull-down 
experiment.}
}
\value{
A dataframe consists of pairwise combindation of preys identified in 
the input with DICE scores.
}
\description{
DICE
The Dice coefficient is used to score the interaction affinity between two proteins.
}
\examples{
data(TestDatInput)
datScore <- DICE(TestDatInput)
head(datScore)
}
\references{
Bing Zhang et al., From pull-down data to protein interaction 
networks and complexes with biological relevance, Bioinformatics, 
Volume 24, Issue 7, 1 April 2008, Pages 979–986, 
\url{https://doi.org/10.1093/bioinformatics/btn036}
}
\author{
Qingzhou Zhang, \email{zqzneptune@hotmail.com}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CompPASS.R
\name{CompPASS}
\alias{CompPASS}
\title{CompPASS}
\usage{
CompPASS(datInput)
}
\arguments{
\item{datInput}{A dataframe with column names: idRun, idBait, idPrey, 
countPrey. Each row represent one unique protein captured in one 
pull-down experiment}
}
\value{
A data frame consists of unique bait-prey pairs with 
Z-score, S-score,D-score and WD-score indicating interacting probabilities.
}
\description{
CompPASS
Comparative Proteomic Analysis Software Suite (CompPASS) is based on spoke
model. This algorithm was developed by Dr. Mathew Sowa for defining the
human deubiquitinating enzyme interaction landscape
(Sowa, Mathew E., et al., 2009). The implementation of this algorithm was
inspired by Dr. Sowa's online tutorial
(\url{http://besra.hms.harvard.edu/ipmsmsdbs/cgi-bin/tutorial.cgi}).
The output includes Z-score, S-score, D-score and WD-score.
This function also computes entropy and normalized 
WD-score. The source  code for this function was based on the source code. 
 \url{https://github.com/dnusinow/cRomppass}
}
\examples{
data(TestDatInput)
datScore <- CompPASS(TestDatInput)
head(datScore)
}
\references{
Sowa, Mathew E., et al. "Defining the human deubiquitinating
enzyme interaction landscape." Cell 138.2 (2009): 389-403.
\url{https://doi.org/10.1016/j.cell.2009.04.042}

Huttlin, Edward L., et al. "The BioPlex network: a systematic 
exploration of the human interactome." Cell 162.2 (2015): 425-440. 
\url{https://doi.org/10.1016/j.cell.2015.06.043}

Huttlin, Edward L., et al. "Architecture of the human 
interactome defines protein communities and disease networks." 
Nature 545.7655 (2017): 505. 
\url{https://www.nature.com/articles/nature22366}
}
\author{
Qingzhou Zhang, \email{zqzneptune@hotmail.com}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PE.R
\name{PE}
\alias{PE}
\title{PE}
\usage{
PE(datInput, rBait = 0.37, cntPseudo = 1)
}
\arguments{
\item{datInput}{A dataframe with column names: idRun, idBait, idPrey, 
Each row represent one unique protein captured in one pull-down 
experiment.}

\item{rBait}{The value of the 'r' parameter as desribed in the publication.}

\item{cntPseudo}{The value of the 'pseudo count' parameter.}
}
\value{
A dataframe consists of protein-protein interactions from both Spoke 
and Matrix model.
}
\description{
PE
Incorporated both spoke and matrix model.
}
\examples{
data(TestDatInput)
datScore <- PE(TestDatInput, 0.37, 1)
head(datScore)
}
\references{
Collins, Sean R., et al. "Toward a comprehensive atlas of the 
physical interactome of Saccharomyces cerevisiae." 
Molecular & Cellular Proteomics 6.3 (2007): 439-450.
\url{https://doi.org/10.1074/mcp.M600381-MCP200}
}
\author{
Qingzhou Zhang, \email{zqzneptune@hotmail.com}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HG.R
\name{HG}
\alias{HG}
\title{HGScore}
\usage{
HG(datInput)
}
\arguments{
\item{datInput}{A dataframe with column names: idRun, idPrey, countPrey, 
lenPrey. Each row represent one unique protein captured in one pull-down 
experiment.}
}
\value{
A dataframe consists of pairwise combindation of preys identified in 
the input with HG scores indicating interacting probabilities computed from 
negative log transformed Hypergeometric test P-values.
}
\description{
HGScore
Scoring algorithm based on a hypergeometric distribution error model 
(Hart et al.,2007) with incorporation of NSAF (Zybailov, Boris, et al., 2006)
. This algorithm was first introduced to predict the protein complex network 
of Drosophila melanogaster (Guruharsha, K. G., et al., 2011). This scoring 
algorithm was based on matrix model.
}
\examples{
data(TestDatInput)
datScore <- HG(TestDatInput)
head(datScore)
}
\references{
Guruharsha, K. G., et al. 'A protein complex network of 
Drosophila melanogaster.' Cell 147.3 (2011): 690-703.
\url{https://doi.org/10.1016/j.cell.2011.08.047}

Hart, G. Traver, Insuk Lee, and Edward M. Marcotte. 
'A high-accuracy consensus map of yeast protein complexes reveals modular 
nature of gene essentiality.' BMC bioinformatics 8.1 (2007): 236.
\url{https://doi.org/10.1186/1471-2105-8-236}

Zybailov, Boris, et al. 'Statistical analysis of membrane 
proteome expression changes in Saccharomyces c erevisiae.' Journal of 
proteome research 5.9 (2006): 2339-2347.
\url{https://doi.org/10.1021/pr060161n}
}
\author{
Qingzhou Zhang, \email{zqzneptune@hotmail.com}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TestDatInput.R
\docType{data}
\name{TestDatInput}
\alias{TestDatInput}
\title{Test data for SMAD}
\format{
A data frame with 5000 rows and 5 variables
}
\usage{
data(TestDatInput)
}
\description{
It is a subset of unfiltered BioPlex 2.0 consisting of
apoptosis as bait proteins
}
\details{
\itemize{
  \item idRun A unique identifier for one AP-MS run
  \item idBait A unique identifier for the bait protein
  \item idPrey A unique identifier for the prey protein
  \item countPrey Sepctra/Peptider count for the prey protein
  \item lenPrey Protein length for the prey protein
}
}
\keyword{datasets}
